@@ -1,2 +1,2 @@
-from .label import label
+from .label import label, expand_labels
 from .format_labels import format_labels
\ No newline at end of file
